plugin

package
v0.0.0-...-017a473 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 15, 2022 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type NullDevicePlugin

type NullDevicePlugin struct {
	// contains filtered or unexported fields
}

NullDevicePlugin implements the Kubernetes device plugin API

func NewNullDevicePlugin

func NewNullDevicePlugin(resourceName string, socket string) *NullDevicePlugin

NewNullDevicePlugin returns an initialized NullDevicePlugin

func (*NullDevicePlugin) Allocate

Allocate which return list of devices.

func (*NullDevicePlugin) GetDevicePluginOptions

GetDevicePluginOptions returns the values of the optional settings for this plugin

func (*NullDevicePlugin) GetPreferredAllocation

GetPreferredAllocation returns the preferred allocation from the set of devices specified in the request

func (*NullDevicePlugin) ListAndWatch

ListAndWatch lists devices and update that list according to the health status

func (*NullDevicePlugin) PreStartContainer

PreStartContainer is unimplemented for this plugin

func (*NullDevicePlugin) Register

func (m *NullDevicePlugin) Register() error

Register registers the device plugin for the given resourceName with Kubelet.

func (*NullDevicePlugin) Serve

func (m *NullDevicePlugin) Serve() error

Serve starts the gRPC server of the device plugin.

func (*NullDevicePlugin) Start

func (m *NullDevicePlugin) Start() error

Start starts the gRPC server, registers the device plugin with the Kubelet, and starts the device healthchecks.

func (*NullDevicePlugin) Stop

func (m *NullDevicePlugin) Stop() error

Stop stops the gRPC server.

Jump to